@@ -21,11 +21,12 @@ import brewtils.models
 from brewtils.choices import parse
 from brewtils.errors import ModelValidationError, RequestStatusTransitionError
 from brewtils.models import Command as BrewtilsCommand
+from brewtils.models import Event as BrewtilsEvent
+from brewtils.models import Events as BrewtilsEvents
 from brewtils.models import Instance as BrewtilsInstance
 from brewtils.models import Job as BrewtilsJob
 from brewtils.models import Parameter as BrewtilsParameter
 from brewtils.models import Request as BrewtilsRequest
-from bson.objectid import ObjectId
 from mongoengine import (
     CASCADE,
     NULLIFY,
@@ -72,15 +73,15 @@ __all__ = [
     "DateTrigger",
     "CronTrigger",
     "IntervalTrigger",
-    "FileTrigger",
     "Garden",
     "File",
     "FileChunk",
     "Role",
+    "RemoteRole",
     "RoleAssignment",
     "User",
     "RemoteUser",
-    "CommandPublishingBlockList",
+    "CommandPublishingBlocklist",
 ]
 
 REQUEST_MAX_PARAM_SIZE = 5 * 1_000_000
@@ -268,10 +269,15 @@ class Command(MongoModel, EmbeddedDocument):
             )
 
 
+def generate_objectid():
+    return ObjectIdField().to_python(None)
+
+
 class Instance(MongoModel, EmbeddedDocument):
     brewtils_model = brewtils.models.Instance
-
-    id = ObjectIdField(required=True, default=ObjectId, unique=True, primary_key=True)
+    id = ObjectIdField(
+        required=True, default=generate_objectid, unique=True, primary_key=True
+    )
     name = StringField(required=True, default="default")
     description = StringField()
     status = StringField(default="INITIALIZING")
@@ -504,6 +510,8 @@ class Request(MongoModel, Document):
         super(Request, self).save(*args, **kwargs)
         self._post_save()
 
+        return self
+
     def clean(self):
         """Validate before saving to the database"""
 
@@ -700,27 +708,6 @@ class CronTrigger(MongoModel, EmbeddedDocument):
     jitter = IntField(required=False)
 
 
-class FileTrigger(MongoModel, EmbeddedDocument):
-    brewtils_model = brewtils.models.FileTrigger
-
-    pattern = ListField()
-    path = StringField(default=".")
-    recursive = BooleanField(default=False)
-    callbacks = DictField()
-
-    def clean(self):
-        """Validate before saving to the database"""
-        if not list(filter(lambda i: i != "", self.pattern)):
-            raise ModelValidationError(
-                "Cannot save FileTrigger. Must have at least one non-empty pattern."
-            )
-
-        if True not in self.callbacks.values():
-            raise ModelValidationError(
-                "Cannot save FileTrigger. Must have at least one callback selected."
-            )
-
-
 class Job(MongoModel, Document):
     brewtils_model = brewtils.models.Job
 
@@ -748,7 +735,6 @@ class Job(MongoModel, Document):
         "date": DateTrigger,
         "cron": CronTrigger,
         "interval": IntervalTrigger,
-        "file": FileTrigger,
     }
 
     name = StringField(required=True)
@@ -912,10 +898,11 @@ class RawFile(Document):
     meta = {"queryset_class": FileFieldHandlingQuerySet}
 
 
-class CommandPublishingBlockList(Document):
+class CommandPublishingBlocklist(Document):
     namespace = StringField(required=True)
     system = StringField(required=True)
     command = StringField(required=True)
+    status = StringField(required=False)
 
     meta = {
         "indexes": [{"fields": ["namespace", "system", "command"], "unique": True}],
@@ -923,14 +910,74 @@ class CommandPublishingBlockList(Document):
 
 
 class Role(Document):
-    name = StringField()
+    name = StringField(required=True)
     description = StringField()
     permissions = ListField(field=StringField(), validation=validate_permissions)
+    protected = BooleanField(default=False)
 
     meta = {
         "indexes": [{"name": "unique_index", "fields": ["name"], "unique": True}],
     }
 
+    def __str__(self) -> str:
+        return self.name
+
+    def save(self, publish: bool = True, *args, **kwargs):
+        """The regular mongoengine Document save(), with an optional event published
+        about the update.
+
+        Args:
+            publish: Whether or not to publish an event after the save. Default: True
+
+        Returns:
+            Role: The saved Role (self)
+        """
+        super().save(*args, **kwargs)
+
+        if publish:
+            self._publish_role_updated()
+
+        return self
+
+    def _publish_role_updated(self):
+        """Publish an event with the updated role information"""
+        # We use publish rather than publish_event here so that we can hijack the
+        # metadata field to store our actual data. This is done to avoid needing to deal
+        # in brewtils models, which the publish_event decorator requires us to do.
+        from beer_garden.events import publish
+
+        publish(
+            BrewtilsEvent(
+                name=BrewtilsEvents.ROLE_UPDATED.name,
+                metadata={
+                    "garden": config.get("garden.name"),
+                    "role": {
+                        "name": self.name,
+                        "description": self.description,
+                        "permissions": self.permissions,
+                    },
+                },
+            )
+        )
+
+
+class RemoteRole(Document):
+    name = StringField(required=True)
+    garden = StringField(required=True)
+    description = StringField()
+    permissions = ListField(field=StringField(), required=False)
+    updated_at = DateTimeField(required=True, default=datetime.datetime.utcnow)
+
+    meta = {
+        "indexes": [
+            {"fields": ["name"]},
+            {"fields": ["garden", "name"], "unique": True},
+        ],
+    }
+
+    def __str__(self):
+        return f"{self.garden}:{self.name}"
+
 
 class RoleAssignmentDomain(EmbeddedDocument):
     scope = StringField(required=True, choices=["Garden", "Global", "System"])
