@@ -160,8 +160,12 @@ route_functions = {
     "RUNNER_RESCAN": beer_garden.local_plugins.manager.rescan,
     "PUBLISH_EVENT": beer_garden.events.publish,
     "USER_SYNC": beer_garden.user.user_sync,
-    "COMMAND_BLOCKLIST_ADD": beer_garden.command_publishing_blocklist.command_publishing_blocklist_add,
-    "COMMAND_BLOCKLIST_REMOVE": beer_garden.command_publishing_blocklist.command_publishing_blocklist_delete,
+    "COMMAND_BLOCKLIST_ADD": (
+        beer_garden.command_publishing_blocklist.command_publishing_blocklist_add
+    ),
+    "COMMAND_BLOCKLIST_REMOVE": (
+        beer_garden.command_publishing_blocklist.command_publishing_blocklist_delete
+    ),
 }
 
 
@@ -578,7 +582,8 @@ def _target_from_type(operation: Operation) -> str:
         )
         or "PUBLISH_EVENT" in operation.operation_type
         or "RUNNER" in operation.operation_type
-        or operation.operation_type in ("PLUGIN_LOG_RELOAD", "SYSTEM_CREATE")
+        or operation.operation_type
+        in ("PLUGIN_LOG_RELOAD", "QUEUE_DELETE_ALL", "SYSTEM_CREATE")
     ):
         return config.get("garden.name")
 
